"""Interfaces with PyPI and Python modules for running the module fast."""
from .usages import Usages


def main():
    """Runs Usages' method `runType()`"""
    Usages()


if __name__ == "__main__":
    main()



"""Contains tools for interacting with PyAutoGUI"""
import pyautogui
import numpy as np


class System:
    """
    This class provides methods for capturing screenshots and simulating mouse actions.

    Attributes:
        None

    Methods:
        - image(): Take a screenshot.
        - mouse(dataPoint, clicks): Move the mouse pointer to specified
          screen coordinates and perform the given number of mouse clicks.

    Notes:
        This class only uses the PyAutoGUI library for system interactions.
        Please refer to the README for KeyFlare the latest installation instructions.

    Example:
        >>> system = System()
        >>> screenshot = system.image()
        >>> print(screenshot.shape)  # Output: (screen_height, screen_width, 3)
        >>> dataPoint = (500, 300)  # Example screen coordinates
        >>> system.mouse(dataPoint)  # Performs a single left-click at (500, 300)
    """

    def image(self):
        """
        Take a screenshot without your mouse in the image.

        Returns:
            np.ndarray: A NumPy array representing the screenshot image.

        Notes:
            This method uses the `pyautogui.screenshot()` function
            to capture a screenshot of the entire current screen.
            PyAutoGUI has a number of system requirements that differ depending on the OS.
            Please check the README for the latest installation instructions for KeyFlare.

        Example:
            >>> system = System()
            >>> screenshot = system.image()
            >>> print(screenshot.shape)  # Output: (screen_height, screen_width, 3)
        """
        screenshot = pyautogui.screenshot()
        return np.array(screenshot)

    def mouse(self, datapoint, clicks):
        """
        Moves the mouse pointer to a specified screen coordinate
        and then performs a number of clicks.

        Args:
            dataPoint (tuple or list, required):
                A tuple or list representing the target screen coordinates (x, y).
            clicks (int, required): The number of mouse clicks to perform.

        Returns:
            None

        Notes:
            This method uses the `pyautogui.moveTo()` and
            `pyautogui.click()` functions to perform these mouse actions.
            Again, PyAutoGUI has a number of varying system requirements.
            Please check the README for the latest installation instructions for KeyFlare.

        Example:
            >>> system = System()
            >>> dataPoint = (500, 300)  # 500 right, 300 down of the top-right corner of the screen.
            >>> system.mouse(dataPoint)  # Performs a single left-click at (500, 300)
        """
        pyautogui.moveTo(datapoint[0], datapoint[1])
        pyautogui.click(clicks=clicks)



from setuptools import setup, find_packages


def main():
    setup(
        name="keyflare",
        version="1.1.3",
        author="Pranit Shah",
        author_email="ppshah2023@gmail.com",
        description="Control your mouse with your keyboard through KeyFlare",
        long_description=open("README.md").read(),
        long_description_content_type="text/markdown",
        packages=find_packages(exclude=["tests*", "test_*", "*tests*"]),
        url="https://github.com/Pshah2023/keyflare",
        install_requires=[
            "numpy==1.24.3",
            "opencv-python==4.7.0.72",
            "Pillow==9.5.0",
            "PyAutoGUI==0.9.54",
            "pynput==1.7.6",
            "pyperclip==1.8.2",
            "pyscreenshot==3.1",
            "Rtree==1.0.1",
        ],
        extras_require={
            "dev": [
                "pytesseract==0.3.1",
                "twine==4.0.2",
                "wheel==0.41.3",
                "pytest==7.4.2",
                "pytest-benchmark==4.0.0",
                "setuptools==68.2.2",
            ]
        },
        license="MIT",
        classifiers=[
            "Development Status :: 5 - Production/Stable",
            "Intended Audience :: Developers",
            "License :: OSI Approved :: MIT License",
            "Programming Language :: Python :: 3",
            "Topic :: Software Development :: Libraries :: Python Modules",
            "Topic :: Utilities",
        ],
        entry_points={
            "console_scripts": [
                "keyflare=keyflare.__main__:main",
            ],
        },
    )


if __name__ == "__main__":
    main()
